<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Život postoji i van browsera!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verzija %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencirano na: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je besplatan program ali njegov razvoj zahtjeva dragocjeno vrijeme.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Vaša &lt;a href=&apos;%1&apos;&gt;donacija&lt;/a&gt; će pomoći daljnjem razvoju %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Prevedite %1 na svoj jezik koristeći %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Dizajn ikone %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Izdano pod &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Unesite pojedinosti za licencu</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-pošta:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kod:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Molimo registrirajte %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Vaša probna verzija je istekla.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Bez licence, ovaj će program isteći za %1 dana</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Kupnjom pune verzije podržati ćete i naporan rad uložen u izradu %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Koristi probnu verziju.</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Unesi licencu</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Kupi licencu</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Od %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Svi videozapisi</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Ne pregledani videozapisi</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Posljednje ažurirano</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Posljednje dodano</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Posljednje gledano</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Najviše gledano</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortiraj po</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Označi sve kao pogledano</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Prikaži ažurirano</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Niste pretplaćeni na ni jedan kanal. Za pretplatu kliknite na zvijezdicu.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Svi videozapisi</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Nepregledani videozapisi</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Trenutno nema dostupnih ažuriranja pretplata</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 pregleda</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bajtova</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bajtova/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekundi</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuta</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 preostalo</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 preuzet u %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Preuzimanje završeno</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Promijeni odredište preuzimanja...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Odaberi odredište preuzimanja</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Odredište preuzimanja promijenjeno.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Trenutna preuzimanja će i dalje ići u prethodno odredište.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Preuzimam u: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Preuzimanja</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reinstall</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Pokreni/Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stani</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stani nakon trenutne stvari.</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Slijedeća</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Prethodna</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Pojačaj zvuk</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Stišaj zvuk</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nijemo</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Premotaj naprijed</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Premotaj nazad</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Pretraga videozapisa i kanala po ključnoj riječi</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Pretraga</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Pretraga videozapisa po kategoriji</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Pretplate</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Pretplatnički kanali</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Udobno se smjestite</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Prozor</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Smanji</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Zaustavi</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stani i vrati se na pretraživanje</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;rethodni</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Idi nazad na prethodnu pjesmu</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Preskoči</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Preskoči na slijedeći videozapis</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Sviraj</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>&amp;Nastavi sviranje</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Cijeli ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Prikaži preko cijelog ekrana</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompaktni mod</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Sakrij play listu i alatnu traku</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Otvori &amp;YouTube stranicu</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Idi na Youtube stranicu sa videom i pauziraj</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopiraj YouTube &amp;link</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopiraj YouTube link trenutnog videa u clipboard</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopiraj &amp;URL video streama</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopiraj &amp;URL trenutnog video streama u clipboard</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Nađi &amp;dijelove videa</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Nađi ostale dijelove videa, nadam se u pravom redoslijedu</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Ukloni</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Ukloni odabrane videozapise iz play liste</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Pomakni &amp;gore</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Pomakni gore označene videozapise u play listi</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Pomakni &amp;dolje</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Pomakni dolje označene videozapise u play listi</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Izbriši nedavne pretrage</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Očisti povijest pretraga. Ne može se poništiti.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kraj</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Doviđenja</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Web stranice</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na webu</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Izvrši &amp;donaciju</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Molim Vas da podržite daljnji razvoj %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informacije o %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Utišaj zvuk</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Ručno pokreni reprodukciju</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Ručno pokreni reprodukciju videa</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Preuzimanja</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Pokaži informacije o preuzimanjima videa</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Preuzimanje</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Preuzmi trenutni video</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp; Pretplata na Kanal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Podijeli trenutni video koristeći %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-pošta</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Budi na vrhu</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Stani nakon ovog videa</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Prijavi problem</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Suzi pretragu</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Više...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Sličan videosadržaj</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Pogledajte video sadržaj sličan ovome</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Otvori u pretraživaču...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Kupi %1</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Program</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Sviraj</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Play lista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Podijeli</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Pregled</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pritisnite %1 za glasnije, %2 za tiše</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Odaberi lokaciju sadržaja</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otvaram %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Da li stvarno želite napustiti %1 dok traje preuzimanje?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Ako sada zatvorite %1, preuzimanje će biti poništeno.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Zatvori i poništi preuzimanje</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Pričekaj da završi preuzimanje</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Greška: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pauziraj</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Izađi iz &amp;Cijelog ekrana</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Preostalo vrijeme: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Glasnoća na %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Zvuk je ugašen</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Zvuk je upaljen</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimalna video rezolucija postavljena na %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Vaša privatnost je sada sigurna</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Preuzimanja završena</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 verzija %2 je dostupna.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Podsjeti me kasnije</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Ažuriraj</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Sada možete zalijepiti Youtube link u neki drugi program</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Sada možete zalijepiti link video streama u neki drugi program</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Link će biti valjan samo ograničeno vrijeme.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Preuzimam %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>od</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>dio</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>nastavak</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Poslano sa %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Odjava sa %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Pretplata na %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Dostupna je nova verzija %1</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 verzija je sad dostupna. Vi imate %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Želite li sada započeti preuzimanje?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>preskoči ovu verziju</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Podsjeti me kasnije</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instaliraj ažuriranja</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Zalijepi</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 od %2 (%3) - %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Pripremam</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nije izvršeno</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Dovršeno</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zaustavljeno</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Zaustavi preuzimanje</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Prikaži u %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Otvori nadmapu</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Ponovno pokreni preuzimanje</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Prikaži %1 više</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nema videozapisa</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nema više videozapisa</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sortiraj po</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevantnost</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Broj pregleda</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Ocjena</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Bilo kada</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danas</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dana</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dana</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Sve</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kratko</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Srednje</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Dugo</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Kraće od 4 minute</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Između 4 i 20 minuta</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Duže od 20 minuta</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvaliteta</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Visoka razlučivost</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p ili više</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Gotovo</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Gotovo</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Dobrodošli u &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>da počnete gledati video.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>ključna riječ</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Unesi</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Nedavne ključne riječi</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Nedavni kanali</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Preuzmi punu verziju</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Nazad</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Naprijed na %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Natrag na %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Suzi pretragu</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Dali ste mislili: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Promijeni odredište preuzimanja...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Najpopularnije</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Preuzimam ažuriranja...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgija</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Čile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbija</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Češka Republika</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egipat</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francuska</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Njemačka</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Gana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grčka</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Mađarska</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indija</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonezija</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irska</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Izrael</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italija</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordan</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenija</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malezija</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Meksiko</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nizozemska</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Novi Zeland</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigerija</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipini</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Poljska</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusija</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudijska Arabija</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sjeverna Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Sjeverna Koreja</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Španjolska</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Švedska</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Tajvan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunis</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turska</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Ujedinjeni Arapski Emirati</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Ujedinjeno Kraljevstvo</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Širom svijeta</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Ne mogu naći video stream za %1</translation>
    </message>
</context>
</TS>